package com.ruoyi.model.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletServiceLog;
import com.ruoyi.model.service.IAppletServiceLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletServiceLog")
public class AppletServiceLogController extends BaseController
{
    @Autowired
    private IAppletServiceLogService appletServiceLogService;

    /**
     * 查询服务记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletServiceLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletServiceLog appletServiceLog)
    {
        startPage();
        List<AppletServiceLog> list = appletServiceLogService.selectAppletServiceLogList(appletServiceLog);
        return getDataTable(list);
    }

    /**
     * 导出服务记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletServiceLog:export')")
    @Log(title = "服务记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletServiceLog appletServiceLog)
    {
//        List<AppletServiceLog> list = appletServiceLogService.selectAppletServiceLogList(appletServiceLog);
//        ExcelUtil<AppletServiceLog> util = new ExcelUtil<AppletServiceLog>(AppletServiceLog.class);
//        util.exportExcel(response, list, "服务记录数据");
    }

    /**
     * 获取服务记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletServiceLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletServiceLogService.selectAppletServiceLogById(id));
    }

    /**
     * 新增服务记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppletServiceLog:add')")
    @Log(title = "服务记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletServiceLog appletServiceLog)
    {
        return toAjax(appletServiceLogService.insertAppletServiceLog(appletServiceLog));
    }

    /**
     * 修改服务记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppletServiceLog:edit')")
    @Log(title = "服务记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletServiceLog appletServiceLog)
    {
        return toAjax(appletServiceLogService.updateAppletServiceLog(appletServiceLog));
    }

    /**
     * 删除服务记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppletServiceLog:remove')")
    @Log(title = "服务记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletServiceLogService.deleteAppletServiceLogByIds(ids));
    }
}
